@@ -49,10 +49,12 @@ struct _DictoFormat {
 };
 
 typedef enum {
+	DICTO_STATE_UNKNOWN=0,
     DICTO_STATE_STOPPED,
     DICTO_STATE_READY,
     DICTO_STATE_PLAYING,
     DICTO_STATE_RECORDING,
+	DICTO_STATE_PAUSED,
     DICTO_STATE_ERROR,
 } DictoState;
 
@@ -81,6 +83,7 @@ struct _DictoClass {
 	void (*refresh) (Dicto *dicto, gpointer data);
 	void (*ready) (Dicto *dicto, gpointer data);
 	void (*level) (Dicto *dicto, gdouble level, gpointer data);
+	void (*paused_play) (Dicto *dicto, gpointer data);
 };
 
 GType dicto_get_type(void);
@@ -96,6 +99,7 @@ gboolean dicto_toggle_record(Dicto *d, const gchar *file);
 
 gboolean dicto_prepare(Dicto *d, const gchar *file);
 gboolean dicto_play(Dicto *d, const gchar *file);
+gboolean dicto_pause(Dicto *d);
 
 gboolean dicto_stop(Dicto *d);
 gboolean dicto_seek(Dicto *d, gdouble pos);
